/**
 * Copyright (c) 2016-2018 Thales Global Services S.A.S.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Abel Hegedus, Tamas Borbas, Balazs Grill, Peter Lunk, Daniel Segesdi (IncQuery Labs Ltd.) - initial API and implementation
 */
package org.eclipse.emf.diffmerge.patch.runtime.identifier;

import com.google.common.base.Objects;
import com.google.common.base.Optional;
import java.util.Set;
import org.eclipse.emf.diffmerge.patch.runtime.identifier.EObjectLocator;
import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.viatra.query.runtime.base.api.NavigationHelper;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.IterableExtensions;

@SuppressWarnings("all")
public class BaseIndexEObjectLocator implements EObjectLocator {
  private final NavigationHelper navigationHelper;
  
  public BaseIndexEObjectLocator(final NavigationHelper navigationHelper) {
    this.navigationHelper = navigationHelper;
  }
  
  @Override
  public Optional<EObject> locate(final String identifier) {
    Optional<EObject> result = Optional.<EObject>absent();
    final Set<EStructuralFeature.Setting> owners = this.navigationHelper.findByAttributeValue(identifier);
    final Function1<EStructuralFeature.Setting, Boolean> _function = (EStructuralFeature.Setting it) -> {
      EAttribute _eIDAttribute = it.getEObject().eClass().getEIDAttribute();
      EStructuralFeature _eStructuralFeature = it.getEStructuralFeature();
      return Boolean.valueOf(Objects.equal(_eIDAttribute, _eStructuralFeature));
    };
    final Iterable<EStructuralFeature.Setting> idSettings = IterableExtensions.<EStructuralFeature.Setting>filter(owners, _function);
    int _size = IterableExtensions.size(idSettings);
    boolean _equals = (_size == 1);
    if (_equals) {
      result = Optional.<EObject>fromNullable(owners.iterator().next().getEObject());
    }
    return result;
  }
  
  public void dispose() {
    this.navigationHelper.dispose();
  }
}
